<?php
namespace THM\DownloadExplorer\Tests\Unit\Controller;
/***************************************************************
 *  Copyright notice
 *
 *  (c) 2014 Jan Haffner <info@jan-haffner.de>
 *  			Rafael Kähm <Rafael@Kaehms.de>
 *  			Samuel Mehrbrodt <samuel.mehrbrodt@mni.thm.de>
 *  			
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Test case for class THM\DownloadExplorer\Controller\StandardController.
 *
 * @author Jan Haffner <info@jan-haffner.de>
 * @author Rafael Kähm <Rafael@Kaehms.de>
 * @author Samuel Mehrbrodt <samuel.mehrbrodt@mni.thm.de>
 */
class StandardControllerTest extends \TYPO3\CMS\Core\Tests\UnitTestCase {

	/**
	 * @var \THM\DownloadExplorer\Controller\StandardController
	 */
	protected $subject = NULL;

	protected function setUp() {
		$this->subject = $this->getMock('THM\\DownloadExplorer\\Controller\\StandardController', array('redirect', 'forward', 'addFlashMessage'), array(), '', FALSE);
	}

	protected function tearDown() {
		unset($this->subject);
	}

	/**
	 * @test
	 */
	public function listActionFetchesAllStandardsFromRepositoryAndAssignsThemToView() {

		$allStandards = $this->getMock('TYPO3\\CMS\\Extbase\\Persistence\\ObjectStorage', array(), array(), '', FALSE);

		$standardRepository = $this->getMock('', array('findAll'), array(), '', FALSE);
		$standardRepository->expects($this->once())->method('findAll')->will($this->returnValue($allStandards));
		$this->inject($this->subject, 'standardRepository', $standardRepository);

		$view = $this->getMock('TYPO3\\CMS\\Extbase\\Mvc\\View\\ViewInterface');
		$view->expects($this->once())->method('assign')->with('standards', $allStandards);
		$this->inject($this->subject, 'view', $view);

		$this->subject->listAction();
	}

	/**
	 * @test
	 */
	public function showActionAssignsTheGivenStandardToView() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$view = $this->getMock('TYPO3\\CMS\\Extbase\\Mvc\\View\\ViewInterface');
		$this->inject($this->subject, 'view', $view);
		$view->expects($this->once())->method('assign')->with('standard', $standard);

		$this->subject->showAction($standard);
	}

	/**
	 * @test
	 */
	public function newActionAssignsTheGivenStandardToView() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$view = $this->getMock('TYPO3\\CMS\\Extbase\\Mvc\\View\\ViewInterface');
		$view->expects($this->once())->method('assign')->with('newStandard', $standard);
		$this->inject($this->subject, 'view', $view);

		$this->subject->newAction($standard);
	}

	/**
	 * @test
	 */
	public function createActionAddsTheGivenStandardToStandardRepository() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$standardRepository = $this->getMock('', array('add'), array(), '', FALSE);
		$standardRepository->expects($this->once())->method('add')->with($standard);
		$this->inject($this->subject, 'standardRepository', $standardRepository);

		$this->subject->createAction($standard);
	}

	/**
	 * @test
	 */
	public function editActionAssignsTheGivenStandardToView() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$view = $this->getMock('TYPO3\\CMS\\Extbase\\Mvc\\View\\ViewInterface');
		$this->inject($this->subject, 'view', $view);
		$view->expects($this->once())->method('assign')->with('standard', $standard);

		$this->subject->editAction($standard);
	}

	/**
	 * @test
	 */
	public function updateActionUpdatesTheGivenStandardInStandardRepository() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$standardRepository = $this->getMock('', array('update'), array(), '', FALSE);
		$standardRepository->expects($this->once())->method('update')->with($standard);
		$this->inject($this->subject, 'standardRepository', $standardRepository);

		$this->subject->updateAction($standard);
	}

	/**
	 * @test
	 */
	public function deleteActionRemovesTheGivenStandardFromStandardRepository() {
		$standard = new \THM\DownloadExplorer\Domain\Model\Standard();

		$standardRepository = $this->getMock('', array('remove'), array(), '', FALSE);
		$standardRepository->expects($this->once())->method('remove')->with($standard);
		$this->inject($this->subject, 'standardRepository', $standardRepository);

		$this->subject->deleteAction($standard);
	}
}
